@@ -36,6 +36,7 @@ public:
     void authenticate();
 
 Q_SIGNALS:
+    void busyChanged(bool busy);
     void promptForSecret(const QString &msg);
     void prompt(const QString &msg);
     void infoMessage(const QString &msg);
@@ -61,6 +62,12 @@ int PamWorker::converse(int n, const struct pam_message **msg, struct pam_respon
 {
     PamWorker *c = static_cast<PamWorker *>(data);
 
+    *resp = (struct pam_response *)calloc(n, sizeof(struct pam_response));
+    if (!*resp) {
+        return PAM_BUF_ERR;
+    }
+    Q_ASSERT(resp);
+
     for (int i = 0; i < n; i++) {
         bool isSecret = false;
         switch (msg[i]->msg_style) {
@@ -68,11 +75,7 @@ int PamWorker::converse(int n, const struct pam_message **msg, struct pam_respon
             isSecret = true;
             Q_FALLTHROUGH();
         case PAM_PROMPT_ECHO_ON:
-            Q_ASSERT(resp);
-            *resp = (struct pam_response *)calloc(n, sizeof(struct pam_response));
-            if (!*resp) {
-                return PAM_BUF_ERR;
-            }
+            Q_EMIT c->busyChanged(false);
 
             const QString prompt = QString::fromLocal8Bit(msg[i]->msg);
             if (isSecret) {
@@ -96,6 +99,8 @@ int PamWorker::converse(int n, const struct pam_message **msg, struct pam_respon
                 return rc;
             }
 
+            Q_EMIT c->busyChanged(true);
+
             resp[i]->resp = (char *)malloc(response.length() + 1);
             // on error, get rid of everything
             if (!resp[i]->resp) {
@@ -152,7 +157,11 @@ void PamWorker::authenticate()
     int rc = pam_authenticate(m_handle, 0); // PAM_SILENT);
     qCDebug(KSCREENLOCKER_GREET) << "Auth done RC" << rc;
 
+    Q_EMIT busyChanged(false);
+
     if (rc == PAM_SUCCESS) {
+        rc = pam_setcred(m_handle, PAM_REFRESH_CRED);
+        /* ignore errors on refresh credentials. If this did not work we use the old ones. */
         Q_EMIT succeeded();
     } else {
         Q_EMIT failed();
@@ -196,6 +205,7 @@ PamAuthenticator::PamAuthenticator(const QString &service, const QString &user,
 
     connect(&m_thread, &QThread::finished, d, &QObject::deleteLater);
 
+    connect(d, &PamWorker::busyChanged, this, &PamAuthenticator::setBusy);
     connect(d, &PamWorker::prompt, this, &PamAuthenticator::prompt);
     connect(d, &PamWorker::promptForSecret, this, &PamAuthenticator::promptForSecret);
     connect(d, &PamWorker::infoMessage, this, &PamAuthenticator::infoMessage);
@@ -225,6 +235,19 @@ void PamAuthenticator::init(const QString &service, const QString &user)
     });
 }
 
+bool PamAuthenticator::isBusy() const
+{
+    return m_busy;
+}
+
+void PamAuthenticator::setBusy(bool busy)
+{
+    if (m_busy != busy) {
+        m_busy = busy;
+        Q_EMIT busyChanged();
+    }
+}
+
 bool PamAuthenticator::isUnlocked() const
 {
     return m_unlocked;
