@@ -32,8 +32,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kscreenlocker_logging.h"
 #include <config-kscreenlocker.h>
 
+#include "config-unix.h"
 #include "waylandserver.h"
-#include <config-X11.h>
 // KDE
 #include <KAuthorized>
 #include <KGlobalAccel>
@@ -44,6 +44,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 // Qt
 #include <QAction>
+#include <QFile>
 #include <QKeyEvent>
 #include <QProcess>
 #include <QTimer>
@@ -55,7 +56,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // X11
 #include <X11/Xlib.h>
 #include <xcb/xcb.h>
-#ifdef X11_Xinput_FOUND
+#if X11_Xinput_FOUND
 #include <X11/extensions/XInput2.h>
 #endif
 // other
@@ -126,7 +127,7 @@ static bool s_logindExit = false;
 
 static bool hasXInput()
 {
-#ifdef X11_Xinput_FOUND
+#if X11_Xinput_FOUND
     Display *dpy = QX11Info::display();
     int xi_opcode, event, error;
     // init XInput extension
@@ -455,7 +456,7 @@ bool KSldApp::establishGrab()
         return false;
     }
 
-#ifdef X11_Xinput_FOUND
+#if X11_Xinput_FOUND
     if (m_hasXInput2) {
         // get all devices
         Display *dpy = QX11Info::display();
@@ -536,7 +537,7 @@ void KSldApp::doUnlock()
         xcb_ungrab_keyboard(c, XCB_CURRENT_TIME);
         xcb_ungrab_pointer(c, XCB_CURRENT_TIME);
         xcb_flush(c);
-#ifdef X11_Xinput_FOUND
+#if X11_Xinput_FOUND
         if (m_hasXInput2) {
             // get all devices
             Display *dpy = QX11Info::display();
